# quotientai Python Client

## Overview

`quotientai` is an SDK and CLI built to manage your workflows on Quotient AI, the AI Evaluation Company.

We are currently in closed beta. For more information on how to get early access visit us at [QuotientAI.co](https://www.quotientai.co/)

## Support
For assistance and inquiries: [support@quotientai.co](mailto:support@quotientai.co)
